<template>
    <div
        element-loading-text="数据加载中..."
        element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)"
        v-loading.fullscreen.lock="loading"
    >
        <el-dialog
            v-dialogDrag
            :title="type + '广场舞地点'"
            :visible="visible"
            :before-close="handleClose"
            :close-on-click-modal="false"
            v-if="visible"
            width="50%"
            top="6vh"
            :class="[loading ? 'dialog-box' : '']"
        >
            <div>
                <el-form
                    ref="form"
                    :rules="rules"
                    :model="formData"
                    label-width="80px"
                >
                    <el-row>
                        <el-col :span="12">
                            <el-form-item
                                label="广场名称"
                                prop="squareLocationName"
                            >
                                <el-input
                                    style="width: 100%"
                                    clearable
                                    v-model="formData.squareLocationName"
                                    placeholder="请输入广场名称"
                                ></el-input>
                            </el-form-item>
                        </el-col>
                        <el-col :span="12">
                            <el-form-item label="简称" prop="shortName">
                                <el-input
                                    style="width: 100%"
                                    clearable
                                    v-model="formData.shortName"
                                    placeholder="请输入简称"
                                ></el-input>
                            </el-form-item>
                        </el-col>
                    </el-row>
                    <el-row>
                        <el-col :span="12">
                            <el-form-item label="行政区划" prop="areaCode">
                                <el-cascader
                                    ref="cascader"
                                    style="width: 100%"
                                    v-model="areaCode"
                                    :props="{label: 'name', value: 'code'}"
                                    :show-all-levels="false"
                                    @change="handleChange"
                                    :options="options"
                                    placeholder="请选择行政区划"
                                ></el-cascader>
                            </el-form-item>
                        </el-col>
                        <el-col :span="24">
                            <el-form-item label="详细地址" prop="detailAddress">
                                <el-input
                                    type="textarea"
                                    style="width: 100%"
                                    clearable
                                    v-model="formData.detailAddress"
                                    placeholder="请输入详细地址"
                                ></el-input>
                            </el-form-item>
                        </el-col>
                    </el-row>
                    <!-- <el-row>
                        <el-col :span="12">
                            <el-form-item label="噪音标准" prop="noiseTypeId">
                                <el-cascader
                                    style="width: 100%"
                                    v-model="noise"
                                    :props="{label: 'name', value: 'id'}"
                                    :show-all-levels="false"
                                    @change="handleNoise"
                                    :options="noiseOptions"
                                ></el-cascader>
                            </el-form-item>
                        </el-col>
                        <el-col :span="12">
                            <el-form-item label="组织团体" prop="level">
                                <el-select
                                    style="width: 100%"
                                    v-model="squareTeam"
                                    multiple
                                    placeholder="请选择组织团体"
                                >
                                    <el-option
                                        v-for="item in squareTeamList"
                                        :key="item.id"
                                        :label="item.name"
                                        :value="item.id"
                                    >
                                    </el-option>
                                </el-select>
                            </el-form-item>
                        </el-col>
                    </el-row> -->
                    <el-row>
                        <el-col :span="12">
                            <el-form-item label="经度" prop="lgtd">
                                <el-input-number
                                    style="width: 100%"
                                    v-model="formData.lgtd"
                                    placeholder="请输入经度"
                                    controls-position="right"
                                    :min="-180"
                                    :max="180"
                                    :precision="6"
                                ></el-input-number>
                            </el-form-item>
                        </el-col>
                        <el-col :span="12">
                            <el-form-item label="纬度" prop="lttd">
                                <el-input-number
                                    style="width: 100%"
                                    v-model="formData.lttd"
                                    placeholder="请输入纬度"
                                    controls-position="right"
                                    :min="-90"
                                    :max="90"
                                    :precision="6"
                                ></el-input-number>
                            </el-form-item>
                        </el-col>
                    </el-row>
                </el-form>
            </div>
            <div
                slot="footer"
                class="dialog-footer"
                :style="loading ? 'position: relative;z-index: -1;' : ''"
            >
                <el-button @click="handleClose">取消</el-button>
                <el-button
                    type="primary"
                    @click="handleSave"
                    :loading="btnLoading"
                    >确定</el-button
                >
            </div>
        </el-dialog>
    </div>
</template>
        
<script>
import utils from '@/utils.js'
import PlazaLocation from '@/api/basicConfiguration/PlazaLocation'
import Team from '@/api/basicConfiguration/Team'

export default {
    props: {},
    name: 'PersonalDialog',
    data() {
        return {
            visible: false,
            loading: false,
            rules: {
                squareLocationName: [
                    {
                        required: true,
                        message: '请输入广场名称',
                        trigger: 'blur',
                    },
                ],
                shortName: [
                    {
                        required: true,
                        message: '请输入简称',
                        trigger: 'blur',
                    },
                ],
                noiseTypeId: [
                    {
                        required: true,
                        message: '请选择噪音标准',
                        trigger: 'blur',
                    },
                ],
                detailAddress: [
                    {
                        required: true,
                        message: '请选择详细地址',
                        trigger: 'blur',
                    },
                ],
                areaCode: [
                    {
                        required: true,
                        message: '请选择行政区划',
                        trigger: 'blur',
                    },
                ],
            },
            xboptions: [],
            type: '新增',
            formData: {},
            areaCode: [],
            options: [],
            noise: [], //噪音标准
            noiseOptions: [], //噪音下拉数据
            squareTeam: [],
            squareTeamList: [], //组织团队
            btnLoading: false,
        }
    },
    created() {
        this.getTownTree()
        this.getNoiseTree()
        this.getTeam()
    },
    methods: {
        //行政区划
        getTownTree() {
            Team.townTree({}, (res) => {
                if (res.state) {
                    this.options = res.value
                    console.log(res.value)
                }
            })
        },
        handleChange(val) {
            this.$nextTick(() => {
                let nodesObj = this.$refs['cascader'].getCheckedNodes()
                console.log(nodesObj)
                if (nodesObj.length) {
                    this.formData.areaCode = nodesObj[0].data.code
                    this.formData.areaFullCode = nodesObj[0].data.fullCode
                    this.formData.areaFullName = nodesObj[0].data.fullName
                } else {
                    this.formData.areaCode = ''
                    this.formData.areaFullCode = ''
                    this.formData.areaFullName = ''
                }
            })
        },
        //噪音标准
        getNoiseTree() {
            PlazaLocation.getNoise({}, (res) => {
                if (res.state) {
                    this.noiseOptions = res.value
                }
            })
        },
        handleNoise(val) {
            let arr = JSON.parse(JSON.stringify(val))
            this.formData.noiseTypeId = arr[0] ? arr[0] : ''
            this.formData.noiseLevelId = arr[1] ? arr[1] : ''
        },
        //组织团队
        getTeam() {
            Team.dataQuery(
                {
                    pageBean: {
                        page: 1,
                        pageSize: -1,
                    },
                },
                (res) => {
                    if (res.rows) {
                        this.squareTeamList = res.rows
                    }
                }
            )
        },
        open(data) {
            this.noise = []
            this.squareTeam = []
            this.areaCode = []
            this.visible = true
            this.formData = {}
            this.type = '新增'
        },
        handleClose() {
            this.visible = false
        },
        submitForm(formName) {
            this.$refs.form.validate((valid) => {
                if (valid) {
                    alert('submit!')
                } else {
                    console.log('error submit!!')
                    return false
                }
            })
        },
        edit(val) {
            this.noise = []
            this.squareTeam = []
            this.areaCode = []
            this.formData = {}
            this.type = '编辑'
            this.visible = true
            PlazaLocation.detailId(val, (res) => {
                if (res) {
                    this.formData = res
                    if (res.squareTeamList) {
                        res.squareTeamList.forEach((e) => {
                            this.squareTeam.push(e.teamFillingId)
                        })
                    }
                    this.areaCode = res.areaFullCode
                        ? res.areaFullCode.split('/').splice(1)
                        : []
                    console.log(this.areaCode)
                    if (res.noiseLevelId && res.noiseTypeId) {
                        this.noise = [res.noiseTypeId, res.noiseLevelId]
                    } else if (res.noiseTypeId) {
                        this.noise = [res.noiseTypeId]
                    } else {
                        this.noise = []
                    }
                }
            })
        },
        handleSave() {
            this.$refs.form.validate((valid) => {
                if (valid) {
                    this.btnLoading = true
                    // this.formData.squareTeamList = []
                    // this.squareTeam.forEach((e) => {
                    //     this.formData.squareTeamList.push({
                    //         teamFillingId: e,
                    //     })
                    // })
                    let method
                    if (this.type === '新增') {
                        method = PlazaLocation.addSave
                    } else {
                        method = PlazaLocation.upData
                    }
                    method(this.formData, (response) => {
                        if (response.state) {
                            this.$notify({
                                type: 'success',
                                message: this.type + '成功',
                                duration: 2000,
                            })
                            this.handleClose()
                            this.$emit('getData')
                        } else {
                            this.$message.warning(response.message)
                        }
                        this.btnLoading = false
                    })
                } else {
                    this.$notify({
                        type: 'warning',
                        message: '请完善表单信息！',
                        duration: 2000,
                    })
                }
            })
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/.el-dialog__wrapper {
  overflow: hidden;
}

.dialog-footer {
  display: flex;
  justify-content: flex-end;
}

//加载遮罩
/deep/.el-dialog__body {
  box-sizing: border-box;

  .el-loading-parent--relative {
    max-height: inherit;
  }
}
</style>